.. _examples:

Examples
============

Here is a list of example notebooks to illustrate how to use earthkit-regrid.

.. toctree::
    :maxdepth: 1

    numpy_arrays.ipynb
    healpix_fieldlist.ipynb
    octahedral_fieldlist.ipynb
